import requests

BASE_URL = 'https://api.github.com/users/{username}/gists'


def get_gists(username):
    url = BASE_URL.format(username=username)
    resp = requests.get(url, params={'per_page': 100})
    if not resp.ok:
        return None
    return resp.json()



from gist_search.utils import get_gists


def search_gists(username, description=None, file_name=None):
    if not description and not file_name:
        print("At least one serach parameter must be specified")
        return

    gists = get_gists(username)
    if gists is None:
        print("Couldn't find gists for user: {}".format(username))
        return

    results = []
    for gist in gists:
        if description and description not in gist['description'].lower():
            continue
        if file_name:
            matched = False
            for fname, fbody in gist['files'].items():
                if file_name in fname:
                    matched = True
                    break
            if not matched:
                continue
        results.append(gist)

    return results



from setuptools import setup, find_packages


setup(
    name='search-gists',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    version='0.1',
    description='Search pubic gists for user',
    author='Santiago Basulto',
    author_email='santiago.basulto@gmail.com',
    url='https://rmotr.com',
    install_requires=[
        'click==6.7',
        'requests==2.18.4'
    ],
    extras_require={  # Optional
        'dev': [
            'pytest==3.4.1',
            'responses==0.8.1'
        ]
    },
    entry_points={  # Optional
        'console_scripts': [
            'search-gists=main:main',
        ],
    },
)
